Description Usage Arguments Value Super classes Methods
Key-value dictionary contains formula class objects.
This class is used maily to define a model's response variable and features
and passed to Options class. Note that all formulas must have
the same labels (response variable).
1 |
... |
Key and value pairs. |
A new Formulas class object.
Dict::Dict -> ml4e::Option -> Formulas
new()Construct a new Formulas class object.
Formulas$new(...)
...Key and value pairs.
A new Formulas class object
print()Print object.
Formulas$print()
add()Adds key and value pairs.
Formulas$add(...)
...Key and value pairs. Checked if the labels (response variabel) is the same with the current items.
Formulas object by invisible(self).
clone()The objects of this class are cloneable with this method.
Formulas$clone(deep = FALSE)
deepWhether to make a deep clone.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.