Description Usage Arguments Value Active bindings Methods
A class stores all machine learning project Option. This class checks if the option have valid values each other. (e.g. All data in Datasets have the label variable described in the formulas, or all models support the task type, etc.)
Methods that do actual tasks are not defined in the classs. The concept is, gather the all options in one place and pass it to Task and Project classes.
1 2 3 4 5 6 7 8 9 10 |
formulas |
A Formulas class object. |
datasets |
A Datasets class object. |
seeds |
A Seeds class object. |
models |
A Models class object. |
measure |
A Measure class object. If |
show_progress |
A logical scalar wheather to show a progress bar. |
keep_data |
A logical scalar wheather to keep original data.
If |
parallel |
A logical scalar wheather to calculate parallely. |
A new Options class object
formulasA Formulas class object.
datasetsA Datasets class object.
seedsA Seeds class object.
modelsA Models class object.
measureA Measure class object.
show_progressWheather to show progress messages.
keep_dataWheather to keep data.
parallelWheather to calculate parallely.
labelsA vector of labels (response variable).
label_varA label (response) variable name.
label_levelsLevels of label (response) variable.
task_typeA task type.
new()Construct a new Options class object.
Options$new( formulas = NULL, datasets = NULL, seeds = NULL, models = NULL, measure = NULL, show_progress = TRUE, keep_data = FALSE, parallel = FALSE )
formulasA Formulas class object.
datasetsA Datasets class object.
seedsA Seeds class object.
modelsA Models class object.
measureA Measure class object. If NULL, a Measure class
object with default metrics are used.
show_progressA logical scalar wheather to show a progress bar.
keep_dataA logical scalar wheather to keep original data.
If TRUE, the original dataset are kept in predicted values and
cross-validation folds.
parallelA logical scalar wheather to calculate parallely.
A new Options class object
print()Print object.
Options$print()
print_options()Print Options object.
Options$print_options(title = " Options ", key_width = 10L)
titleA character scalar of printed title.
key_widthA integer scalar of key column width.
clone()The objects of this class are cloneable with this method.
Options$clone(deep = FALSE)
deepWhether to make a deep clone.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.