Description Usage Arguments Value Super classes Methods
Key-value dictionary contains call class objects. The calls must be calls
that generate rset class object from rsample::rsample package.
This class is usually passed to Datasets class then used to generate
resamples from datasets.
1 |
... |
Key and value pairs. |
A new ResampleCalls class object.
Dict::Dict -> ml4e::Option -> ResampleCalls
new()Construct a new ResampleCalls class object.
ResampleCalls$new(...)
...Key and value pairs.
A new ResampleCalls class object
print()Print object.
ResampleCalls$print()
get_resample()Get resample data.
ResampleCalls$get_resample(data = NULL, resample_call_key = NULL, seed = NULL)
dataA data.frame to be converted to a resample.
resample_call_keyA character or integer scalar of the resample_calls keys.
seedA integer scalar seed.
A resample of rset class object.
clone()The objects of this class are cloneable with this method.
ResampleCalls$clone(deep = FALSE)
deepWhether to make a deep clone.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.