SearchBase: SearchBase Class

Description Super class Active bindings Methods

Description

A base class describe a hyper parameter search task.

Super class

ml4e::Task -> SearchBase

Active bindings

result

A task result.

Methods

Public methods

Inherited methods

Method new()

Construct a new SearchBase class object.

Usage
SearchBase$new(options = NULL, keys = NULL)
Arguments
options

A Options class object.

keys

A named character vector of keys.

Returns

A new SearchBase class object


Method print()

Print object.

Usage
SearchBase$print()

Method get_rank()

Get parameters ranking tables.

Usage
SearchBase$get_rank(metric_name = NULL, n = 5L)
Arguments
metric_name

A character scalar of metric name. If NULL, the first metric_name in self$options$measure$metric_names is used.

n

A integer scalar of a number of the ranking.

Returns

A list of parameters ranking by keys


Method get_best_param()

Get best parameters.

Usage
SearchBase$get_best_param(metric_name = NULL)
Arguments
metric_name

A character scalar of metric name. If NULL, the first metric_name in self$options$measure$metric_names is used.

Returns

A list of parameters.


Method clone()

The objects of this class are cloneable with this method.

Usage
SearchBase$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.


five-dots/ml4e documentation built on June 19, 2020, 4:26 p.m.