Description Usage Arguments Value Super class Active bindings Methods
A class defines a bayesian search task specification.
1 | new_search_bayes(options = NULL, keys = NULL, metric_name = NULL)
|
options |
A Options class object. |
keys |
A named character vector of keys. |
metric_name |
A character scalar of metric_name. |
A new SearchBayes class object
ml4e::Task -> SearchBayes
metric_nameA metric name.
is_new_gridA logical wheather grid is new.
doneA logical if finished
errorA logical if error
resultA task result.
new()Construct a new SearchBayes class object.
SearchBayes$new(options = NULL, keys = NULL, metric_name = NULL)
optionsA Options class object.
keysA named character vector of keys.
metric_nameA character scalar of metric name. If NULL, the first
metric_name in self$options$measure$metric_names is used.
A new SearchBayes class object
print()Print object.
SearchBayes$print()
do()Run a bayesian optimization. The result will be stored in
self$result.
SearchBayes$do( init_grid_dt = NULL, init_points = 4L, n_iter = 5L, acq = "ucb", kappa = 2.576, eps = 0, kernel = list(type = "exponential", power = 2L) )
init_grid_dtA data.frame of init_grid_dt.
init_pointsA integer scalar of init_points.
n_iterA integer scalar of n_iter.
acqA character scalar of acq (aquisition function).
Can be "ucb", "ei" or "poi".
kappaA numeric scalar of kappa.
epsA numeric scalar of eps.
kernelA list of kernal parameters.
A data.frame of best parameters.
clone()The objects of this class are cloneable with this method.
SearchBayes$clone(deep = FALSE)
deepWhether to make a deep clone.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.