Description Usage Arguments Value Super classes Active bindings Methods
A class defines a grid search task specification.
1 | new_search_grid(options = NULL, keys = NULL)
|
options |
A Options class object. |
keys |
A named character vector of keys. |
A new SearchGrid class object
ml4e::Task -> ml4e::SearchBase -> SearchGrid
progressA list of grid calculation progress.
progress_strA character of progress.
doneA logical if finished
new()Construct a new SearchGrid class object.
SearchGrid$new(options = NULL, keys = NULL)
optionsA Options class object.
keysA named character vector of keys.
A new SearchGrid class object
print()Print object.
SearchGrid$print()
do()Run a grid search. The result will be stored in self$result.
SearchGrid$do(num = NULL)
numA integer scalar of how many parameters to be calculated.
If NULL, all parameters in param set will be calculated.
get_count_by_param()Get paramter's counts.
SearchGrid$get_count_by_param()
A data.frame of parameter count.
clone()The objects of this class are cloneable with this method.
SearchGrid$clone(deep = FALSE)
deepWhether to make a deep clone.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.