Description Active bindings Methods
A base class describe a machine learning task specification. A task is
defined by a Options and keys which is named character vector specifiyng
option's key. The main functionality is evaluate quoted call arguments and
assign the acutal values to be called in the later task.
optionsA Options object.
keysA named character vector of keys.
formulasA Formulas object.
datasetsA Datasets object.
seedsA Seeds object.
modelsA Models object.
measureA Measure object.
labelsA vector of labels (response variable).
label_varA label (response) variable name.
label_levelsLevels of label (response) variable.
task_typeA task type.
show_progressWheather to show progress messages.
keep_dataWheather to keep data.
parallelWheather to calculate parallely.
formulaA tasks' formula.
datasetA task's dataset.
trainA task's train data.
testA task's test data.
resample_callA task's resample call.
seedA task's seed.
modelA task's model.
search_seedA task's search seed for resampling.
cv_seedA task's cv seed for resampling.
model_seedA task's model seed.
id_colA task's datasets' id_col.
test_idsA task's datasets' test_ids.
preproc_callA task's preproc call.
data_callA task's data call.
fit_callA task's fit call.
pred_callA task's prediction call.
has_test_labelsWheather the dataset has test labels.
resultA task result.
doneWheather the task is finished.
new()Construct a new Task class object.
Task$new(options = NULL, keys = NULL)
optionsA Options class object.
keysA named character vector of keys. Names must be "formula", "dataset", "resample", "seed", "model", "preproc", "fit_param" and values must be key of the each options.
A new Task class object
print()Print object.
Task$print()
print_task()Print task object.
Task$print_task(title = " Task ", key_width = 14L)
titleA character scalar of printed title.
key_widthA integer scalar of key column width.
eval_call_args()Evaluate call arguments in the task environment.
Task$eval_call_args(call = NULL)
callcall object.
A call object.
clone()The objects of this class are cloneable with this method.
Task$clone(deep = FALSE)
deepWhether to make a deep clone.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.