Description Super class Active bindings Methods
A base class describe a hyper parameter search task.
ml4e::Task -> SearchBase
resultA task result.
new()Construct a new SearchBase class object.
SearchBase$new(options = NULL, keys = NULL)
optionsA Options class object.
keysA named character vector of keys.
A new SearchBase class object
print()Print object.
SearchBase$print()
get_rank()Get parameters ranking tables.
SearchBase$get_rank(metric_name = NULL, n = 5L)
metric_nameA character scalar of metric name. If NULL, the
first metric_name in self$options$measure$metric_names is used.
nA integer scalar of a number of the ranking.
A list of parameters ranking by keys
get_best_param()Get best parameters.
SearchBase$get_best_param(metric_name = NULL)
metric_nameA character scalar of metric name. If NULL, the
first metric_name in self$options$measure$metric_names is used.
A list of parameters.
clone()The objects of this class are cloneable with this method.
SearchBase$clone(deep = FALSE)
deepWhether to make a deep clone.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.